@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-embed-single.h,v 1.34 2005/11/18 19:24:16 chpe Exp $
+ *  $Id: ephy-embed-single.h,v 1.36 2006/01/29 21:09:52 crispin Exp $
  */
 
 #ifndef EPHY_EMBED_SINGLE_H
@@ -60,6 +60,7 @@ struct _EphyEmbedSingleIface
 
 	/* Methods */
 
+	gboolean	  (* init)		(EphyEmbedSingle *single);
 	GtkWidget *	  (* open_window)	(EphyEmbedSingle *single,
 						 EphyEmbed *parent,
 						 const char *address,
@@ -72,10 +73,13 @@ struct _EphyEmbedSingleIface
 	gboolean	  (* get_network_status)(EphyEmbedSingle *single);
 	GList *		  (* get_font_list)	(EphyEmbedSingle *shell,
 						 const char *langGroup);
+	const char *      (* get_backend_name)  (EphyEmbedSingle *shell);
 };
 
 GType		ephy_embed_single_get_type		(void);
 
+gboolean	ephy_embed_single_init			(EphyEmbedSingle *single);
+
 GtkWidget      *ephy_embed_single_open_window		(EphyEmbedSingle *single,
 							 EphyEmbed *parent,
 							 const char *address,
@@ -94,6 +98,8 @@ gboolean	ephy_embed_single_get_network_status	(EphyEmbedSingle *single);
 GList		*ephy_embed_single_get_font_list	(EphyEmbedSingle *single,
 							 const char *lang_group);
 
+const char	*ephy_embed_single_get_backend_name	(EphyEmbedSingle *single);
+
 G_END_DECLS
 
 #endif
