@@ -16,17 +16,13 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: FilePicker.h,v 1.10 2005/04/06 14:29:55 chpe Exp $
+ *  $Id: FilePicker.h,v 1.11 2006/05/10 18:07:00 chpe Exp $
  */
 
 #ifndef EPHY_FILEPICKER_H
 #define EPHY_FILEPICKER_H
 
 #include <nsIFilePicker.h>
-#include <nsISupports.h>
-#undef MOZILLA_INTERNAL_API
-#include <nsEmbedString.h>
-#define MOZILLA_INTERNAL_API 1
 
 #include "ephy-file-chooser.h"
 
@@ -57,7 +53,7 @@ public:
 private:
 	EphyFileChooser *mDialog;
 	PRInt16 mMode;
-	nsEmbedString mDefaultString;
+	nsString mDefaultString;
 };
 
 #endif
