@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-stock-icons.c,v 1.18 2005/10/20 13:33:42 chpe Exp $
+ *  $Id: ephy-stock-icons.c,v 1.22 2006/02/21 13:44:15 paharvey Exp $
  */
 
 #include "config.h"
@@ -43,15 +43,16 @@ ephy_stock_icons_init (void)
 		STOCK_VIEW_SOURCE,
 		STOCK_SEND_MAIL,
 		STOCK_ADD_BOOKMARK,
+		STOCK_BOOKMARK,
 		STOCK_PRINT_SETUP,
 		STOCK_LOCK_INSECURE,
 		STOCK_LOCK_SECURE,
 		STOCK_LOCK_BROKEN,
+		STOCK_DRAG_MODE,
 	};
 
 	static const GtkStockItem items[] =
 	{
-		{ EPHY_STOCK_CLOSE_TAB,	N_("Close Tab"),	0, 0, NULL },
 		{ EPHY_STOCK_POPUPS,	N_("Popup Windows"),	0, 0, NULL },
 		{ EPHY_STOCK_HISTORY,	N_("History"),		0, 0, NULL },
 		{ EPHY_STOCK_BOOKMARKS, N_("Bookmarks"),	0, 0, NULL },
@@ -97,6 +98,4 @@ ephy_stock_icons_init (void)
 
 	gtk_icon_factory_add_default (factory);
 	g_object_unref (factory);
-
-	gtk_icon_size_register (EPHY_ICON_SIZE_TAB_BUTTON, 10, 10);
 }
