@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-node-view.c,v 1.63 2005/10/01 07:38:05 chpe Exp $
+ *  $Id: ephy-node-view.c,v 1.65 2006/01/17 19:35:34 crispin Exp $
  */
 
 #include "config.h"
@@ -1260,6 +1260,14 @@ ephy_node_view_add_column (EphyNodeView *view,
 
 	if (flags & EPHY_NODE_VIEW_SORTABLE)
 	{
+		/* Now we have created a new column, re-create the
+		 * sort model, but ensure that the set_sort function
+		 * hasn't been called, see bug #320686 */
+		g_assert (view->priv->sort_column == -1);
+		g_object_unref (view->priv->sortmodel);
+		view->priv->sortmodel = ephy_tree_model_sort_new (view->priv->filtermodel);
+		gtk_tree_view_set_model (GTK_TREE_VIEW (view), GTK_TREE_MODEL (view->priv->sortmodel));
+
 		gtk_tree_view_column_set_sort_column_id (gcolumn, column);
 	}
 
@@ -1638,14 +1646,14 @@ ephy_node_view_class_init (EphyNodeViewClass *klass)
 					 g_param_spec_pointer ("root",
 							       "Root node",
 							       "Root node",
-							       G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY));
+							       G_PARAM_READWRITE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_CONSTRUCT_ONLY));
 	g_object_class_install_property (object_class,
 					 PROP_FILTER,
 					 g_param_spec_object ("filter",
 							      "Filter object",
 							      "Filter object",
 							      EPHY_TYPE_NODE_FILTER,
-							      G_PARAM_READWRITE));
+							      G_PARAM_READWRITE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB));
 
 	ephy_node_view_signals[NODE_TOGGLED] =
 		g_signal_new ("node_toggled",
