@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-bookmark-action.c,v 1.79.2.1 2006/07/01 13:26:04 chpe Exp $
+ *  $Id: ephy-bookmark-action.c,v 1.79 2006/02/24 14:57:04 paharvey Exp $
  */
 
 #include "config.h"
@@ -135,8 +135,8 @@ ephy_bookmark_action_sync_smart_url (GtkAction *gaction,
 		EphyBookmarkAction *action = EPHY_BOOKMARK_ACTION (gaction);
 		EphyBookmarkActionPrivate *priv = action->priv;
 		gboolean is_smart_url = priv->smart_url;
-		gboolean has_icon = ephy_node_get_property_string
-		  (priv->node, EPHY_NODE_BMK_PROP_ICON) != NULL;
+		gboolean has_icon = (gboolean) ephy_node_get_property_string
+		  (priv->node, EPHY_NODE_BMK_PROP_ICON);		
 		GtkWidget *entry, *icon;
 		guint width;
 
