@@ -1,6 +1,6 @@
 /*
  *  Copyright (C) 2000-2004 Marco Pesenti Gritti
- *  Copyright (C) 2003, 2004 Christian Persch
+ *  Copyright (C) 2003, 2004, 2006 Christian Persch
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-shell.h,v 1.27 2004/06/19 17:21:19 marco Exp $
+ *  $Id: ephy-shell.h,v 1.37 2006/01/25 21:52:27 chpe Exp $
  */
 
 #ifndef EPHY_SHELL_H
@@ -39,33 +39,12 @@ G_BEGIN_DECLS
 #define EPHY_IS_SHELL_CLASS(k)	(G_TYPE_CHECK_CLASS_TYPE ((k), EPHY_TYPE_SHELL))
 #define EPHY_SHELL_GET_CLASS(o)	(G_TYPE_INSTANCE_GET_CLASS ((o), EPHY_TYPE_SHELL, EphyShellClass))
 
-typedef struct EphyShell EphyShell;
-typedef struct EphyShellClass EphyShellClass;
-typedef struct EphyShellPrivate EphyShellPrivate;
+typedef struct _EphyShell		EphyShell;
+typedef struct _EphyShellClass		EphyShellClass;
+typedef struct _EphyShellPrivate	EphyShellPrivate;
 
 extern EphyShell *ephy_shell;
 
-#define EPHY_SHELL_ERROR ephy_shell_error_quark ()
-
-typedef enum
-{
-	EPHY_SHELL_ERROR_MISSING_SERVER,
-	EPHY_SHELL_ERROR_OBJECT_REG_FAILED,
-	EPHY_SHELL_ERROR_FACTORY_REG_FAILED
-} EphyShellError;
-
-typedef enum
-{
-	EPHY_SHELL_STARTUP_TABS			= 1 << 0,
-	EPHY_SHELL_STARTUP_EXISTING_WINDOW	= 1 << 2,
-	EPHY_SHELL_STARTUP_FULLSCREEN		= 1 << 3,
-	EPHY_SHELL_STARTUP_BOOKMARKS_EDITOR	= 1 << 4,
-	EPHY_SHELL_STARTUP_SESSION		= 1 << 5,
-	EPHY_SHELL_STARTUP_IMPORT_BOOKMARKS	= 1 << 6,
-	EPHY_SHELL_STARTUP_ADD_BOOKMARK		= 1 << 7,
-	EPHY_SHELL_STARTUP_SERVER		= 1 << 8
-} EphyShellStartupFlags;
-
 typedef enum
 {
 	/* Page types */
@@ -75,16 +54,17 @@ typedef enum
 
 	/* Page mode */
 	EPHY_NEW_TAB_FULLSCREEN_MODE	= 1 << 4,
+	EPHY_NEW_TAB_DONT_SHOW_WINDOW	= 1 << 5,
 
 	/* Tabs */
 	EPHY_NEW_TAB_APPEND_LAST	= 1 << 7,
 	EPHY_NEW_TAB_APPEND_AFTER	= 1 << 8,
 	EPHY_NEW_TAB_JUMP		= 1 << 9,
 	EPHY_NEW_TAB_IN_NEW_WINDOW	= 1 << 10,
-	EPHY_NEW_TAB_IN_EXISTING_WINDOW	= 1 << 11
+	EPHY_NEW_TAB_IN_EXISTING_WINDOW	= 1 << 11,
 } EphyNewTabFlags;
 
-struct EphyShell
+struct _EphyShell
 {
 	EphyEmbedShell parent;
 
@@ -92,24 +72,16 @@ struct EphyShell
 	EphyShellPrivate *priv;
 };
 
-struct EphyShellClass
+struct _EphyShellClass
 {
 	EphyEmbedShellClass parent_class;
 };
 
+GType		ephy_new_tab_flags_get_type		(void) G_GNUC_CONST;
+
 GType		ephy_shell_get_type			(void);
 
-GQuark		ephy_shell_error_quark			(void);
-
-EphyShell      *ephy_shell_new				(void);
-
-gboolean	ephy_shell_startup			(EphyShell *shell,
-							 EphyShellStartupFlags flags,
-							 const char **args,
-							 const char *string_arg,
-							 GError **error);
-
-EphyWindow     *ephy_shell_get_active_window		(EphyShell *shell);
+EphyShell      *ephy_shell_get_default			(void);
 
 EphyTab	       *ephy_shell_new_tab			(EphyShell *shell,
 							 EphyWindow *parent_window,
@@ -117,8 +89,19 @@ EphyTab	       *ephy_shell_new_tab			(EphyShell *shell,
 							 const char *url,
 							 EphyNewTabFlags flags);
 
+EphyTab	       *ephy_shell_new_tab_full			(EphyShell *shell,
+							 EphyWindow *parent_window,
+							 EphyTab *previous_tab,
+							 const char *url,
+							 EphyNewTabFlags flags,
+							 EphyEmbedChrome chrome,
+							 gboolean is_popup,
+							 guint32 user_time);
+
 GObject	       *ephy_shell_get_session			(EphyShell *shell);
 
+GObject	       *ephy_shell_get_net_monitor		(EphyShell *shell);
+
 EphyBookmarks  *ephy_shell_get_bookmarks		(EphyShell *shell);
 
 GObject	       *ephy_shell_get_toolbars_model		(EphyShell *shell,
@@ -136,6 +119,9 @@ GObject        *ephy_shell_get_prefs_dialog		(EphyShell *shell);
 
 GObject	       *ephy_shell_get_print_setup_dialog	(EphyShell *shell);
 
+/* private API */
+void	       _ephy_shell_create_instance		(void);
+
 G_END_DECLS
 
 #endif
